Package 'riotr'

Title: Interact with the 'Riot Games API'
Description: Download and read data from the Riot Games Developer API (<https://developer.riotgames.com/>). Provides functions for all primary endpoints, including League of Legends, Teamfight Tactics, Legends of Runeterra, and Valorant.
Authors: Christopher T. Kenny [aut, cre] (ORCID: <https://orcid.org/0000-0002-9386-6860>)
Maintainer: Christopher T. Kenny <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-05-28 07:00:55 UTC
Source: https://github.com/christopherkenny/riotr

Help Index


Check or Get RIOT Key

Description

Check or Get RIOT Key

Usage

has_riot_key()

get_riot_key()

Value

logical if has, key if get

Examples

has_riot_key()

Create Tournament Code (Stub)

Description

Creates a tournament code for the given tournament.

Usage

lol_create_tournament_code(tournament_id, count = NULL, body, region = "na1")

Arguments

tournament_id

Tournament ID.

count

Number of codes to generate. Defaults to 1.

body

A list with tournament code parameters including mapType, pickType, spectatorType, teamSize, and optionally allowedParticipants and metadata.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

Value

a character vector of tournament codes

Examples

lol_create_tournament_code(
  tournament_id = 1234,
  body = list(
    mapType = 'SUMMONERS_RIFT',
    pickType = 'TOURNAMENT_DRAFT',
    spectatorType = 'ALL',
    teamSize = 5
  )
)

Get Active Game by PUUID

Description

Returns active game information for the given summoner PUUID.

Usage

lol_get_active_game(puuid, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with active game data or NULL if the player is not in a game. Returns a list if clean = FALSE.

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_active_game(puuid)

Get All Challenge Configs

Description

Get All Challenge Configs

Usage

lol_get_all_challenge_configs(region = "na1", clean = TRUE)

Arguments

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with all challenge configs or a list if clean = FALSE

Examples

lol_get_all_challenge_configs()

Get All Challenge Percentiles

Description

Get All Challenge Percentiles

Usage

lol_get_all_challenge_percentiles(region = "na1", clean = TRUE)

Arguments

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a list of challenge percentiles

Examples

lol_get_all_challenge_percentiles()

Get Challenge Config by ID

Description

Get Challenge Config by ID

Usage

lol_get_challenge_config(challenge_id, region = "na1", clean = TRUE)

Arguments

challenge_id

Challenge ID.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with challenge config or a list if clean = FALSE

Examples

lol_get_challenge_config(1)

Get Challenge Leaderboards

Description

Get Challenge Leaderboards

Usage

lol_get_challenge_leaderboards(
  challenge_id,
  level,
  region = "na1",
  clean = TRUE
)

Arguments

challenge_id

Challenge ID.

level

Level. Such as "MASTER", "GRANDMASTER", or "CHALLENGER".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with leaderboard entries or a list if clean = FALSE

Examples

lol_get_challenge_leaderboards(1, 'MASTER')

Get Challenge Percentiles by ID

Description

Get Challenge Percentiles by ID

Usage

lol_get_challenge_percentiles(challenge_id, region = "na1")

Arguments

challenge_id

Challenge ID.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

Value

a list of challenge percentiles

Examples

lol_get_challenge_percentiles(1)

Get Challenge Player Data

Description

Get Challenge Player Data

Usage

lol_get_challenge_player_data(puuid, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a list with player challenge data

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_challenge_player_data(puuid)

Get Challenger League

Description

Get Challenger League

Usage

lol_get_challenger_league(queue, region = "na1", clean = TRUE)

Arguments

queue

Queue type. Such as "RANKED_SOLO_5x5" or "RANKED_FLEX_SR".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

lol_get_challenger_league('RANKED_SOLO_5x5')

Get All Champion Masteries by PUUID

Description

Get All Champion Masteries by PUUID

Usage

lol_get_champion_masteries(puuid, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with champion mastery data or a list if clean = FALSE

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_champion_masteries(puuid)

Get Champion Mastery by PUUID and Champion ID

Description

Get Champion Mastery by PUUID and Champion ID

Usage

lol_get_champion_mastery(puuid, champion_id, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

champion_id

Champion ID.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with champion mastery data or a list if clean = FALSE

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_champion_mastery(puuid, 1)

Get Champion Mastery Score by PUUID

Description

Get Champion Mastery Score by PUUID

Usage

lol_get_champion_mastery_score(puuid, region = "na1")

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

Value

an integer representing the total champion mastery score

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_champion_mastery_score(puuid)

Get Champion Rotation Information

Description

Returns champion rotations, including free-to-play and low-level free-to-play rotations.

Usage

lol_get_champion_rotations(region = "na1", clean = TRUE)

Arguments

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with champion rotation data or a list if clean = FALSE

Examples

lol_get_champion_rotations()

Get Clash Players by PUUID

Description

Get Clash Players by PUUID

Usage

lol_get_clash_players(puuid, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with player data or a list if clean = FALSE

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_clash_players(puuid)

Get Clash Team by ID

Description

Get Clash Team by ID

Usage

lol_get_clash_team(team_id, region = "na1", clean = TRUE)

Arguments

team_id

Team ID.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with team data, or NULL if not found. Returns a list if clean = FALSE.

Examples

lol_get_clash_team('PLACEHOLDER_CLASH_TEAM_ID')

Get Clash Tournament by ID

Description

Get Clash Tournament by ID

Usage

lol_get_clash_tournament(tournament_id, region = "na1", clean = TRUE)

Arguments

tournament_id

Tournament ID.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with tournament data, or NULL if not found. Returns a list if clean = FALSE.

Examples

lol_get_clash_tournament('PLACEHOLDER_CLASH_TOURNAMENT_ID')

Get Clash Tournament by Team ID

Description

Get Clash Tournament by Team ID

Usage

lol_get_clash_tournament_by_team(team_id, region = "na1", clean = TRUE)

Arguments

team_id

Team ID.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with tournament data, or NULL if not found. Returns a list if clean = FALSE.

Examples

lol_get_clash_tournament_by_team('PLACEHOLDER_CLASH_TEAM_ID')

Get All Clash Tournaments

Description

Get All Clash Tournaments

Usage

lol_get_clash_tournaments(region = "na1", clean = TRUE)

Arguments

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with tournament data or a list if clean = FALSE

Examples

lol_get_clash_tournaments()

Get Grandmaster League

Description

Get Grandmaster League

Usage

lol_get_grandmaster_league(queue, region = "na1", clean = TRUE)

Arguments

queue

Queue type. Such as "RANKED_SOLO_5x5" or "RANKED_FLEX_SR".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

lol_get_grandmaster_league('RANKED_SOLO_5x5')

Get League by ID

Description

Get League by ID

Usage

lol_get_league(league_id, region = "na1", clean = TRUE)

Arguments

league_id

League ID.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

lol_get_league('7ccf5091-303b-3f5a-927b-7705b93e3564')

Get League Entries

Description

Get League Entries

Usage

lol_get_league_entries(queue, tier, division, region = "na1", clean = TRUE)

Arguments

queue

Queue type. Such as "RANKED_SOLO_5x5" or "RANKED_FLEX_SR".

tier

Tier. Such as "DIAMOND", "MASTER", "GRANDMASTER", or "CHALLENGER".

division

Division. Such as "I", "II", "III", or "IV".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

lol_get_league_entries('RANKED_SOLO_5x5', 'DIAMOND', 'I')

Get League Entries by PUUID

Description

Get League Entries by PUUID

Usage

lol_get_league_entries_by_puuid(puuid, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_league_entries_by_puuid(puuid)

Get Experimental League Entries

Description

Get Experimental League Entries

Usage

lol_get_league_exp_entries(queue, tier, division, region = "na1", clean = TRUE)

Arguments

queue

Queue type. Such as "RANKED_SOLO_5x5" or "RANKED_FLEX_SR".

tier

Tier. Such as "DIAMOND", "MASTER", "GRANDMASTER", or "CHALLENGER".

division

Division. Such as "I", "II", "III", or "IV".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

lol_get_league_exp_entries('RANKED_SOLO_5x5', 'DIAMOND', 'I')

Get Lobby Events by Tournament Code

Description

Get Lobby Events by Tournament Code

Usage

lol_get_lobby_events(tournament_code, region = "na1", clean = TRUE)

Arguments

tournament_code

Tournament code.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with lobby events or a list if clean = FALSE

Examples

lol_get_lobby_events('tournament-code')

Get Master League

Description

Get Master League

Usage

lol_get_master_league(queue, region = "na1", clean = TRUE)

Arguments

queue

Queue type. Such as "RANKED_SOLO_5x5" or "RANKED_FLEX_SR".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

lol_get_master_league('RANKED_SOLO_5x5')

Get Match by ID

Description

Get Match by ID

Usage

lol_get_match(match_id, regional = "americas", clean = TRUE)

Arguments

match_id

Match ID.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with match data or a list if clean = FALSE

Examples

lol_get_match('NA1_5494453720')

Get Match IDs by PUUID

Description

Get Match IDs by PUUID

Usage

lol_get_match_ids(
  puuid,
  start = NULL,
  count = NULL,
  queue = NULL,
  type = NULL,
  start_time = NULL,
  end_time = NULL,
  regional = "americas"
)

Arguments

puuid

PUUID of the player.

start

Start index. Defaults to 0.

count

Number of match IDs to return. Defaults to 20.

queue

Queue ID to filter by.

type

Type of match to filter by. Such as "ranked", "normal", "tourney", or "tutorial".

start_time

Epoch timestamp in seconds to filter matches after.

end_time

Epoch timestamp in seconds to filter matches before.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

Value

a character vector of match IDs

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_match_ids(puuid)

Get Match Replays by PUUID

Description

Get Match Replays by PUUID

Usage

lol_get_match_replays(puuid, regional = "americas")

Arguments

puuid

PUUID of the player.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

Value

a character vector of replay URLs

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_match_replays(puuid)

Get Match Timeline

Description

Get Match Timeline

Usage

lol_get_match_timeline(match_id, regional = "americas", clean = TRUE)

Arguments

match_id

Match ID.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a list with timeline data (timelines are complex nested structures)

Examples

lol_get_match_timeline('NA1_5494453720')

Get LoL Platform Data (Status)

Description

Get LoL Platform Data (Status)

Usage

lol_get_platform_data(region = "na1", clean = TRUE)

Arguments

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with platform status data or a list if clean = FALSE

Examples

lol_get_platform_data()

Get Summoner by PUUID

Description

Get Summoner by PUUID

Usage

lol_get_summoner_by_puuid(puuid, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with summoner data or a list if clean = FALSE

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_summoner_by_puuid(puuid)

Get Summoner by Access Token

Description

Returns the summoner associated with the current access token.

Usage

lol_get_summoner_me(region = "na1", clean = TRUE)

Arguments

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with summoner data, or NULL if the request fails. Returns a list if clean = FALSE.

Examples

lol_get_summoner_me()

Get Top Champion Masteries by PUUID

Description

Get Top Champion Masteries by PUUID

Usage

lol_get_top_champion_masteries(
  puuid,
  count = NULL,
  region = "na1",
  clean = TRUE
)

Arguments

puuid

PUUID of the player.

count

Number of entries to return. Defaults to 3.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with top champion mastery data or a list if clean = FALSE

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lol_get_top_champion_masteries(puuid)

Get Tournament Code

Description

Get Tournament Code

Usage

lol_get_tournament_code(tournament_code, region = "na1", clean = TRUE)

Arguments

tournament_code

Tournament code.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with tournament code data or a list if clean = FALSE

Examples

lol_get_tournament_code('tournament-code')

Register Tournament Provider (Stub)

Description

Registers a tournament provider.

Usage

lol_register_provider(body, region = "na1")

Arguments

body

A list with region and url fields.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

Value

an integer provider ID

Examples

lol_register_provider(
  body = list(region = 'NA', url = 'https://example.com')
)

Register Tournament (Stub)

Description

Registers a tournament.

Usage

lol_register_tournament(body, region = "na1")

Arguments

body

A list with name and providerId fields.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

Value

an integer tournament ID

Examples

lol_register_tournament(
  body = list(name = 'My Tournament', providerId = 1)
)

Get LoR Ranked Leaderboards

Description

Get LoR Ranked Leaderboards

Usage

lor_get_leaderboards(regional = "americas", clean = TRUE)

Arguments

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with ranked leaderboard entries or a list if clean = FALSE

Examples

lor_get_leaderboards()

Get LoR Match by ID

Description

Get LoR Match by ID

Usage

lor_get_match(match_id, regional = "americas", clean = TRUE)

Arguments

match_id

Match ID.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with match data, or NULL if not found. Returns a list if clean = FALSE.

Examples

lor_get_match('PLACEHOLDER_LOR_MATCH_ID')

Get LoR Match IDs by PUUID

Description

Get LoR Match IDs by PUUID

Usage

lor_get_match_ids(puuid, regional = "americas")

Arguments

puuid

PUUID of the player.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

Value

a character vector of match IDs

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
lor_get_match_ids(puuid)

Get LoR Platform Data (Status)

Description

Get LoR Platform Data (Status)

Usage

lor_get_platform_data(regional = "americas", clean = TRUE)

Arguments

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with platform status data or a list if clean = FALSE

Examples

lor_get_platform_data()

Get Account by PUUID

Description

Get Account by PUUID

Usage

riot_get_account_by_puuid(puuid, regional = "americas", clean = TRUE)

Arguments

puuid

PUUID of the player.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with account data or a list if clean = FALSE

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
riot_get_account_by_puuid(puuid)

Get Account by PUUID (Esports)

Description

Get Account by PUUID (Esports)

Usage

riot_get_account_by_puuid_esports(puuid, regional = "esports", clean = TRUE)

Arguments

puuid

PUUID of the player.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with account data, or NULL if not found. Returns a list if clean = FALSE.

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
riot_get_account_by_puuid_esports(puuid)

Get Account by Riot ID

Description

Get Account by Riot ID

Usage

riot_get_account_by_riot_id(
  game_name,
  tag_line,
  regional = "americas",
  clean = TRUE
)

Arguments

game_name

Game name of the Riot account.

tag_line

Tag line of the Riot account.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with account data or a list if clean = FALSE

Examples

riot_get_account_by_riot_id('Doublelift', 'NA1')

Get Account by Riot ID (Esports)

Description

Get Account by Riot ID (Esports)

Usage

riot_get_account_by_riot_id_esports(
  game_name,
  tag_line,
  regional = "esports",
  clean = TRUE
)

Arguments

game_name

Game name of the Riot account.

tag_line

Tag line of the Riot account.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with account data, or NULL if not found. Returns a list if clean = FALSE.

Examples

riot_get_account_by_riot_id_esports('Doublelift', 'NA1')

Get Active Region for a Player

Description

Get Active Region for a Player

Usage

riot_get_active_region(game, puuid, regional = "americas", clean = TRUE)

Arguments

game

Game identifier. Such as "val" or "lor".

puuid

PUUID of the player.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with active region data, or NULL if the request fails. Returns a list if clean = FALSE.

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
riot_get_active_region('val', puuid)

Get Active Shard for a Player

Description

Get Active Shard for a Player

Usage

riot_get_active_shard(game, puuid, regional = "americas", clean = TRUE)

Arguments

game

Game identifier. Such as "val" or "lor".

puuid

PUUID of the player.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with active shard data or a list if clean = FALSE

Examples

puuid <- 'O2q8aNv6VBlFz9ABjEoOH8g1d_KO1IQHboIuog8ORd7QOH2L8nGgsYgK-TN16ucwUQsPpihH-tLtAA'
riot_get_active_shard('val', puuid)

Add Entry to Renviron

Description

Adds RIOT API key to .Renviron.

Usage

set_riot_key(key, overwrite = FALSE, install = FALSE, r_env = NULL)

Arguments

key

Character. API key to add to add.

overwrite

Defaults to FALSE. Boolean. Should existing RIOT_KEY in Renviron be overwritten?

install

Defaults to FALSE. Boolean. Should this be added '~/.Renviron' file?

r_env

Path to install to if install is TRUE.

Value

key, invisibly

Examples

example_env <- tempfile(fileext = '.Renviron')
set_riot_key('1234', r_env = example_env)
# r_env should likely be: file.path(Sys.getenv('HOME'), '.Renviron')

Get TFT Challenger League

Description

Get TFT Challenger League

Usage

tft_get_challenger_league(queue = "RANKED_TFT", region = "na1", clean = TRUE)

Arguments

queue

Queue type. Defaults to "RANKED_TFT".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

tft_get_challenger_league()

Get TFT Grandmaster League

Description

Get TFT Grandmaster League

Usage

tft_get_grandmaster_league(queue = "RANKED_TFT", region = "na1", clean = TRUE)

Arguments

queue

Queue type. Defaults to "RANKED_TFT".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

tft_get_grandmaster_league()

Get TFT League Entries

Description

Get TFT League Entries

Usage

tft_get_league_entries(tier, division, region = "na1", clean = TRUE)

Arguments

tier

Tier. Such as "DIAMOND", "MASTER", "GRANDMASTER", or "CHALLENGER".

division

Division. Such as "I", "II", "III", or "IV".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

tft_get_league_entries('DIAMOND', 'I')

Get TFT League Entries by PUUID

Description

Get TFT League Entries by PUUID

Usage

tft_get_league_entries_by_puuid(puuid, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

puuid <- 'GmNPNjUbzbWN8YIA79V4p308eFpf21xPO2Lw8o2xJTJMPW83W54t4GfyfpwOn7-hBz5c3MHpg-Dc3w'
tft_get_league_entries_by_puuid(puuid)

Get TFT Master League

Description

Get TFT Master League

Usage

tft_get_master_league(queue = "RANKED_TFT", region = "na1", clean = TRUE)

Arguments

queue

Queue type. Defaults to "RANKED_TFT".

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with league entries or a list if clean = FALSE

Examples

tft_get_master_league()

Get TFT Match by ID

Description

Get TFT Match by ID

Usage

tft_get_match(match_id, regional = "americas", clean = TRUE)

Arguments

match_id

Match ID.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with match data or a list if clean = FALSE

Examples

tft_get_match('NA1_5501463494')

Get TFT Match IDs by PUUID

Description

Get TFT Match IDs by PUUID

Usage

tft_get_match_ids(
  puuid,
  start = NULL,
  count = NULL,
  start_time = NULL,
  end_time = NULL,
  regional = "americas"
)

Arguments

puuid

PUUID of the player.

start

Start index. Defaults to 0.

count

Number of match IDs to return. Defaults to 20.

start_time

Epoch timestamp in seconds to filter matches after.

end_time

Epoch timestamp in seconds to filter matches before.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

Value

a character vector of match IDs

Examples

puuid <- 'GmNPNjUbzbWN8YIA79V4p308eFpf21xPO2Lw8o2xJTJMPW83W54t4GfyfpwOn7-hBz5c3MHpg-Dc3w'
tft_get_match_ids(puuid)

Get TFT Platform Data (Status)

Description

Get TFT Platform Data (Status)

Usage

tft_get_platform_data(region = "na1", clean = TRUE)

Arguments

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with platform status data or a list if clean = FALSE

Examples

tft_get_platform_data()

Get TFT Summoner by PUUID

Description

Get TFT Summoner by PUUID

Usage

tft_get_summoner_by_puuid(puuid, region = "na1", clean = TRUE)

Arguments

puuid

PUUID of the player.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with summoner data or a list if clean = FALSE

Examples

puuid <- 'GmNPNjUbzbWN8YIA79V4p308eFpf21xPO2Lw8o2xJTJMPW83W54t4GfyfpwOn7-hBz5c3MHpg-Dc3w'
tft_get_summoner_by_puuid(puuid)

Get TFT Summoner by Access Token

Description

Returns the TFT summoner associated with the current access token.

Usage

tft_get_summoner_me(region = "na1", clean = TRUE)

Arguments

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with summoner data, or NULL if the request fails. Returns a list if clean = FALSE.

Examples

tft_get_summoner_me()

Get TFT Top Rated Ladder

Description

Get TFT Top Rated Ladder

Usage

tft_get_top_rated_ladder(queue, region = "na1", clean = TRUE)

Arguments

queue

Queue type for TFT rated ladder.

region

Region routing value. Platform regions include "na1", "euw1", "eun1", "kr", "br1", "jp1", "la1", "la2", "oc1", "tr1", "ru", "ph2", "sg2", "th2", "tw2", "vn2".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with top rated ladder entries or a list if clean = FALSE

Examples

tft_get_top_rated_ladder('RANKED_TFT_TURBO')

Get Valorant Content

Description

Get Valorant Content

Usage

val_get_content(locale = NULL, regional = "na", clean = TRUE)

Arguments

locale

Locale. Such as "en-US", "ja-JP", etc.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a list with Valorant content data

Examples

val_get_content()

Get Valorant Ranked Leaderboard by Act

Description

Get Valorant Ranked Leaderboard by Act

Usage

val_get_leaderboard(
  act_id,
  size = NULL,
  start_index = NULL,
  regional = "na",
  clean = TRUE
)

Arguments

act_id

Act ID.

size

Number of entries to return.

start_index

Start index for pagination.

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with ranked leaderboard entries or a list if clean = FALSE

Examples

val_get_leaderboard('3ea2b318-423b-cf86-25da-7cbb0eefbe2d')

Get Valorant Platform Data (Status)

Description

Get Valorant Platform Data (Status)

Usage

val_get_platform_data(regional = "na", clean = TRUE)

Arguments

regional

Regional routing value. One of "americas", "asia", "europe", "sea", or "esports".

clean

Default is TRUE. Should output be returned as a tibble (TRUE) or list.

Value

a tibble::tibble with platform status data or a list if clean = FALSE

Examples

val_get_platform_data()